@@ -1,11 +1,10 @@
 """EIA Open Data API Client Package."""
 
-__version__ = "0.1.1"
-__author__ = "tayeva"
+__version__ = "0.2.0"
 
 
 from eia_client import api_key
-from eia_client import client
+from eia_client.client import Client
 from eia_client import parse
 from eia_client.api_key import ApiKey
 from eia_client.endpoint import Endpoint, EndpointBuilder
